@@ -14,12 +14,14 @@ extern void bicriterion_iterated_local_search_call(void *, void *, void *, void
 extern void dispersion_anticlustering(void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void distance_anticlustering(void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void kmeans_anticlustering(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void fast_kmeans_anticlustering(void *, void *, void *, void *, void *, void *, void *, void *);
 
 static const R_CMethodDef CEntries[] = {
   {"bicriterion_iterated_local_search_call", (DL_FUNC) &bicriterion_iterated_local_search_call,  10},
   {"dispersion_anticlustering",              (DL_FUNC) &dispersion_anticlustering,               9},
   {"distance_anticlustering",                (DL_FUNC) &distance_anticlustering,                 9},
   {"kmeans_anticlustering",                  (DL_FUNC) &kmeans_anticlustering,                  11},
+  {"fast_kmeans_anticlustering",                  (DL_FUNC) &fast_kmeans_anticlustering,         8},
   {NULL, NULL, 0}
 };
 
